@@ -117,12 +117,19 @@ class Path_Operations:
             write_path.open_operation("w", lambda stream: stream.write(content_json))
         return content_json
 
-    def read(self):
+    def read(self, default=...):
         """ Read this Path with JSON.
 
-            :param generalfile.Path self: """
+            :param generalfile.Path self:
+            :param default: Optionally return a default value. """
         with ReadContext(self) as read_path:
-            return read_path.open_operation("r", lambda stream: json.loads(stream.read()))
+            try:
+                return read_path.open_operation("r", lambda stream: json.loads(stream.read()))
+            except FileNotFoundError as e:
+                if default is ...:
+                    raise e
+                else:
+                    return default
 
     @deco_require_state(exists=True)
     def rename(self, name=None, stem=None, suffix=None, overwrite=False):
@@ -494,6 +501,17 @@ class Path_Operations:
             diff.update({path for path in self_paths.intersection(target_paths) if not (self / path).is_identical(path=target / path)})
         return diff
 
+    def contains(self, text):
+        """ Return whether text string exists in one of the files.
+
+            :param paths tuple[generalfile.Path] self:
+            :param text: """
+        with self.lock():
+            with open(str(self), "r") as stream:
+                for line in stream:
+                    if text in line:
+                        return True
+        return False
 
 
 
